searchData={"content_type":"text/markdown","items":[{"doc":"DetsPlus persistent tuple/struct/map storage.\n\n[DetsPlus](https://github.com/dominicletz/dets_plus) has a similiar API as `dets` but without\nthe 2GB file storage limit. Writes are buffered in an\ninternal ETS table and synced every `auto_save` period\nto the persistent storage.\n\nWhile `sync()` or `auto_save` are in progress the database\nis still readable and writeable.\n\nThere is no commitlog so not synced writes are lost.\nLookups are possible by key and non-matches are accelerated\nusing a bloom filter. The persistent file concept follows\nDJ Bernsteins CDB database format, but uses an Elixir\nencoded header https://cr.yp.to/cdb.html. When syncing\na new CDB database file is created and replaces\nthe old CDB atomically file using `File.rename!` so\ndatabase corruptions are not possible from incomplete updates.\n\nLimits are:\n- Total file size: 18_446 Petabyte\n- Maximum entry size: 4 Gigabyte\n- Maximum entry count: :infinity\n\nExample:\n\n```elixir\n{:ok, dets} = DetsPlus.open_file(:example)\nDetsPlus.insert(dets, {1, 1, 1})\n[{1, 1, 1}] = DetsPlus.lookup(dets, 1)\n:ok =  DetsPlus.close(dets)\n```","ref":"DetsPlus.html","title":"DetsPlus","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"DetsPlus.html#child_spec/1","title":"DetsPlus.child_spec/1","type":"function"},{"doc":"Syncs pending writes to the persistent file and closes the table.","ref":"DetsPlus.html#close/1","title":"DetsPlus.close/1","type":"function"},{"doc":"Returns the number of object in the table. This is an estimate and the same as `info(dets, :size)`.","ref":"DetsPlus.html#count/1","title":"DetsPlus.count/1","type":"function"},{"doc":"Deletes all objects with key Key from table Name.","ref":"DetsPlus.html#delete/2","title":"DetsPlus.delete/2","type":"function"},{"doc":"Deletes all objects from a table in almost constant time.","ref":"DetsPlus.html#delete_all_objects/1","title":"DetsPlus.delete_all_objects/1","type":"function"},{"doc":"Deletes all instances of a specified object from a table.","ref":"DetsPlus.html#delete_object/2","title":"DetsPlus.delete_object/2","type":"function"},{"doc":"Returns information about table Name as a list of objects:\n\n- `{file_size, integer() >= 0}}` - The file size, in bytes.\n- `{filename, file:name()}` - The name of the file where objects are stored.\n- `{keypos, keypos()}` - The key position.\n- `{size, integer() >= 0}` - The number of objects estimated in the table.\n- `{type, type()}` - The table type.","ref":"DetsPlus.html#info/1","title":"DetsPlus.info/1","type":"function"},{"doc":"Returns the information associated with `item` for the table. The following items are allowed:\n\n- `{file_size, integer() >= 0}}` - The file size, in bytes.\n- `{header_size, integer() >= 0}}` - The size of erlang term encoded header.\n- `{bloom_bytes, integer() >= 0}}` - The size of the in-memory and on-disk bloom filter, in bytes.\n- `{hashtable_bytes, integer() >= 0}}` - The size of the on-disk lookup hashtable, in bytes.\n- `{filename, file:name()}` - The name of the file where objects are stored.\n- `{keypos, keypos()}` - The key position.\n- `{size, integer() >= 0}` - The number of objects estimated in the table.\n- `{type, type()}` - The table type.","ref":"DetsPlus.html#info/2","title":"DetsPlus.info/2","type":"function"},{"doc":"Inserts one or more objects into the table. If there already exists an object with a key matching the key of some of the given objects, the old object will be replaced.","ref":"DetsPlus.html#insert/2","title":"DetsPlus.insert/2","type":"function"},{"doc":"Inserts one or more objects into the table. If there already exists an object with a key matching the key of some of the given objects, the old object will be replaced.","ref":"DetsPlus.html#insert_new/2","title":"DetsPlus.insert_new/2","type":"function"},{"doc":"Returns a list of all objects with key Key stored in the table.\n\nExample:\n\n```\n2> State.open_file(:abc)\n{ok,:abc}\n3> State.insert(:abc, {1,2,3})\nok\n4> State.insert(:abc, {1,3,4})\nok\n5> State.lookup(:abc, 1).\n[{1,3,4}]\n```\n\nIf the table type is set, the function returns either the empty list or a list with one object, as there cannot be more than one object with a given key. If the table type is bag or duplicate_bag, the function returns a list of arbitrary length.\n\nNotice that the order of objects returned is unspecified. In particular, the order in which objects were inserted is not reflected.","ref":"DetsPlus.html#lookup/2","title":"DetsPlus.lookup/2","type":"function"},{"doc":"Same as `member?/2`","ref":"DetsPlus.html#member/2","title":"DetsPlus.member/2","type":"function"},{"doc":"Works like `lookup/2`, but does not return the objects. Returns true if one or more table elements has the key `key`, otherwise false.","ref":"DetsPlus.html#member?/2","title":"DetsPlus.member?/2","type":"function"},{"doc":"Opens an existing table or creates a new table. If no\n  `file` argument is provided the table name will be used.\n  Dets registers a Process under the provided name which can\n  be used for calling alternatively to the pid.\n\n  Arguments:\n\n  - `file` - An optional path + filename for the database file.\n  - `auto_save` - The autosave interval. If the interval is an integer Time, the table is flushed to disk whenever it is not accessed for Time milliseconds. If the interval is the atom infinity, autosave is disabled. Defaults to `180_000` (3 minutes).\n  - `auto_save_memory` - The autosave threshold in memory. When the internal ETS table reaches a size bigger than this the table is flushed to disk. Defaults to `1_000_000_000` (1 GB)\n  - `page_cache_memory` - The amount of memory to use for file system caching. Defaults to `1_000_000_000` (1 GB)\n  - `keypos` - The position of the element of each object to be used as key. Defaults to 1. The ability to explicitly state the key position is most convenient when we want to store Erlang records in which the first position of the record is the name of the record type.","ref":"DetsPlus.html#open_file/2","title":"DetsPlus.open_file/2","type":"function"},{"doc":"Reducer function following the `Enum` protocol.","ref":"DetsPlus.html#reduce/3","title":"DetsPlus.reduce/3","type":"function"},{"doc":"Starts a sync of all changes to the disk. Same as `sync/1` but doesn't block","ref":"DetsPlus.html#start_sync/1","title":"DetsPlus.start_sync/1","type":"function"},{"doc":"Ensures that all updates made to table are written to disk. While the sync is running the\ntable can still be used for reads and writes, but writes issued after the `sync/1` call\nwill not be part of the persistent file. These new changes will only be included in the\nnext sync call.","ref":"DetsPlus.html#sync/1","title":"DetsPlus.sync/1","type":"function"},{"doc":"","ref":"DetsPlus.html#t:t/0","title":"DetsPlus.t/0","type":"type"},{"doc":"Alpha version of a sharded DetsPlus","ref":"KrakenDB.html","title":"KrakenDB","type":"module"},{"doc":"Syncs pending writes to the persistent file and closes the table.","ref":"KrakenDB.html#close/1","title":"KrakenDB.close/1","type":"function"},{"doc":"Returns the number of object in the table. This is an estimate.","ref":"KrakenDB.html#count/1","title":"KrakenDB.count/1","type":"function"},{"doc":"Deletes all objects with key Key from table Name.","ref":"KrakenDB.html#delete/2","title":"KrakenDB.delete/2","type":"function"},{"doc":"Deletes all objects from a table in almost constant time.","ref":"KrakenDB.html#delete_all_objects/1","title":"KrakenDB.delete_all_objects/1","type":"function"},{"doc":"Deletes all instances of a specified object from a table.","ref":"KrakenDB.html#delete_object/2","title":"KrakenDB.delete_object/2","type":"function"},{"doc":"Returns information about table Name as a list of objects:\n\n- `{file_size, integer() >= 0}}` - The file size sum, in bytes.\n- `{directory, file:name()}` - The name of the directory where objects are stored.\n- `{keypos, keypos()}` - The key position.\n- `{size, integer() >= 0}` - The number of objects estimated in the table.\n- `{type, type()}` - The table type.","ref":"KrakenDB.html#info/1","title":"KrakenDB.info/1","type":"function"},{"doc":"Returns the information associated with `item` for the table. The following items are allowed:\n\n- `{file_size, integer() >= 0}}` - The file size, in bytes.\n- `{header_size, integer() >= 0}}` - The size of erlang term encoded header.\n- `{bloom_bytes, integer() >= 0}}` - The size of the in-memory and on-disk bloom filter, in bytes.\n- `{hashtable_bytes, integer() >= 0}}` - The size of the on-disk lookup hashtable, in bytes.\n- `{filename, file:name()}` - The name of the file where objects are stored.\n- `{keypos, keypos()}` - The key position.\n- `{size, integer() >= 0}` - The number of objects estimated in the table.\n- `{type, type()}` - The table type.","ref":"KrakenDB.html#info/2","title":"KrakenDB.info/2","type":"function"},{"doc":"Inserts one or more objects into the table. If there already exists an object with a key matching the key of some of the given objects, the old object will be replaced.","ref":"KrakenDB.html#insert/2","title":"KrakenDB.insert/2","type":"function"},{"doc":"Inserts one object into the table if it doesn't already exists.","ref":"KrakenDB.html#insert_new/2","title":"KrakenDB.insert_new/2","type":"function"},{"doc":"Returns a list of all objects with key Key stored in the table.\n\nExample:\n\n```\n2> KrakenDB.open_directory(:abc)\n{ok,:abc}\n3> KrakenDB.insert(:abc, {1,2,3})\nok\n4> KrakenDB.insert(:abc, {1,3,4})\nok\n5> KrakenDB.lookup(:abc, 1).\n[{1,3,4}]\n```\n\nIf the table type is set, the function returns either the empty list or a list with one object, as there cannot be more than one object with a given key. If the table type is bag or duplicate_bag, the function returns a list of arbitrary length.\n\nNotice that the order of objects returned is unspecified. In particular, the order in which objects were inserted is not reflected.","ref":"KrakenDB.html#lookup/2","title":"KrakenDB.lookup/2","type":"function"},{"doc":"Works like `lookup/2`, but does not return the objects. Returns true if one or more table elements has the key `key`, otherwise false.","ref":"KrakenDB.html#member?/2","title":"KrakenDB.member?/2","type":"function"},{"doc":"","ref":"KrakenDB.html#open_directory/2","title":"KrakenDB.open_directory/2","type":"function"},{"doc":"Reducer function following the `Enum` protocol.","ref":"KrakenDB.html#reduce/3","title":"KrakenDB.reduce/3","type":"function"},{"doc":"Starts a sync of all changes to the disk. Same as `sync/1` but doesn't block","ref":"KrakenDB.html#start_sync/1","title":"KrakenDB.start_sync/1","type":"function"},{"doc":"Ensures that all updates made to table are written to disk. While the sync is running the\ntable can still be used for reads and writes, but writes issued after the `sync/1` call\nwill not be part of the persistent file. These new changes will only be included in the\nnext sync call.","ref":"KrakenDB.html#sync/1","title":"KrakenDB.sync/1","type":"function"},{"doc":"","ref":"KrakenDB.html#t:t/0","title":"KrakenDB.t/0","type":"type"}],"producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}